#!/bin/bash

./update.pl --pot
echo ""
./abi-extract.pl -N gl-ES
./abi-extract.pl -N nb-NO
./abi-extract.pl -N sv-SE
./abi-extract.pl -N de-DE
./abi-extract.pl -N hu-HU
./abi-extract.pl -N uk-UA 
./abi-extract.pl -N ca-ES 
./abi-extract.pl -N nl-NL 
./abi-extract.pl -N id-ID 
./abi-extract.pl -N pl-PL 
./abi-extract.pl -N zh-CN 
./abi-extract.pl -N cs-CZ 
./abi-extract.pl -N es-ES 
./abi-extract.pl -N it-IT      
./abi-extract.pl -N pt-BR 
./abi-extract.pl -N zh-TW 
./abi-extract.pl -N cy-GB 
./abi-extract.pl -N fi-FI 
./abi-extract.pl -N hr-HR 
./abi-extract.pl -N lt-LT 
./abi-extract.pl -N pt-PT 
./abi-extract.pl -N da-DK 
./abi-extract.pl -N fr-FR 
./abi-extract.pl -N nn-NO 
./abi-extract.pl -N ru-RU 
./abi-extract.pl -N bg-BG 
./abi-extract.pl -N tr-TR
./abi-extract.pl -N ta-IN
./abi-extract.pl -N qu-BO
./abi-extract.pl -N ast-ES
./abi-extract.pl -N ku
./abi-extract.pl -N ms-MY
./abi-extract.pl -N ne-NP
